@@ -10,13 +10,13 @@ BIGWIG_BIN_SIZE="{ integer > 0 }"
 # --- MODULES ---
 echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
-module load python/3.8 java/13.0
+module load python/3.9 java/13.0
 module load fastqc/0.11 bowtie2/2.4 bismark/0.22 samtools/1.12
-virtualenv --no-download "$SLURM_TMPDIR/env.python.3.8"
-source "$SLURM_TMPDIR/env.python.3.8/bin/activate" &&
+virtualenv --no-download "$SLURM_TMPDIR/env.python.3"
+source "$SLURM_TMPDIR/env.python.3/bin/activate" &&
 pip install --no-index --quiet --upgrade pip &&
 pip install --no-index --quiet numpy scipy matplotlib pandas deepTools==3.5.0
-chmod +x "$SLURM_TMPDIR/env.python.3.8/bin/"* 2> /dev/null
+chmod +x "$SLURM_TMPDIR/env.python.3/bin/"* 2> /dev/null
 
 
 # --- FUNCTIONS ---
