@@ -13,13 +13,13 @@ MACS2_GENOME_SIZE="{ regex mm|hs|cc|dm|[0-9]+ }"
 # --- MODULES ---
 echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
-module load python/3.8 java/13.0
+module load python/3.9 java/13.0
 module load fastqc/0.11 bowtie2/2.4 samtools/1.12
-virtualenv --no-download "$SLURM_TMPDIR/env.python.3.8"
-source "$SLURM_TMPDIR/env.python.3.8/bin/activate" &&
+virtualenv --no-download "$SLURM_TMPDIR/env.python.3"
+source "$SLURM_TMPDIR/env.python.3/bin/activate" &&
 pip install --no-index --quiet --upgrade pip &&
 pip install --no-index --quiet numpy scipy matplotlib pandas deepTools==3.5.0 MACS2==2.2.7.1
-chmod +x "$SLURM_TMPDIR/env.python.3.8/bin/"* 2> /dev/null
+chmod +x "$SLURM_TMPDIR/env.python.3/bin/"* 2> /dev/null
 
 
 # --- FUNCTIONS ---
