@@ -13,13 +13,13 @@ module reset
 export MUGQIC_INSTALL_HOME="/cvmfs/soft.mugqic/CentOS6"
 module use "$MUGQIC_INSTALL_HOME/modulefiles"
 module load StdEnv/2020 gcc/9.3
-module load python/3.8 java/13.0
+module load python/3.9 java/13.0
 module load fastqc/0.11 bowtie2/2.4 samtools/1.12 mugqic/homer/4.11
-virtualenv --no-download "$SLURM_TMPDIR/env.python.3.8"
-source "$SLURM_TMPDIR/env.python.3.8/bin/activate" &&
+virtualenv --no-download "$SLURM_TMPDIR/env.python.3"
+source "$SLURM_TMPDIR/env.python.3/bin/activate" &&
 pip install --no-index --quiet --upgrade pip &&
 pip install --no-index --quiet numpy scipy matplotlib pandas deepTools==3.5.0
-chmod +x "$SLURM_TMPDIR/env.python.3.8/bin/"* 2> /dev/null
+chmod +x "$SLURM_TMPDIR/env.python.3/bin/"* 2> /dev/null
 
 
 # --- FUNCTIONS ---
